<h1 align='center'>
    <picture>
    <source media="(prefers-color-scheme: dark)" srcset="docs/_static/cogsworth-logo-darkmode.png">
    <source media="(prefers-color-scheme: light)" srcset="docs/_static/cogsworth-logo.png">
    <img width=500 alt='cogsworth-logo' src="docs/_static/cogsworth-logo.png">
    </picture>
    <br>
  <a href="https://raw.githubusercontent.com/TomWagg/cogsworth/paper/paper/ApJS/apjs_paper.pdf">
      <img src="https://img.shields.io/badge/read-paper-blue.svg?style=flat" alt="Read the article"/>
  </a>

  <a href='https://cogsworth.readthedocs.io/en/latest/?badge=latest'>
      <img src='https://readthedocs.org/projects/cogsworth/badge/?version=latest' alt='Documentation Status' />
  </a>
  <a href="https://codecov.io/github/TomWagg/cogsworth" > 
      <img src="https://codecov.io/github/TomWagg/cogsworth/graph/badge.svg?token=L2WGWNLJQU"/> 
  </a>
  <a href="https://github.com/TomWagg/cogsworth/actions/workflows/test_cogsworth.yml" > 
      <img src="https://github.com/TomWagg/cogsworth/actions/workflows/test_cogsworth.yml/badge.svg"/> 
  </a>
  <a href="mailto:tomjwagg@gmail.com">
      <img src="https://img.shields.io/badge/contact-authors-blueviolet.svg?style=flat" alt="Email the authors"/>
  </a>
</h1>
<h4 align="center">cogsworth is a Python package for performing seamlessly self-consistent population synthesis and galactic dynamics simulations!</h4>

### Installation
[![PyPI version](https://badge.fury.io/py/cogsworth.svg)](https://badge.fury.io/py/cogsworth)

A quick and easy `pip install cogsworth` will cover most use cases, but we recommend using a conda environment as well. Check out the full instructions [here](https://cogsworth.readthedocs.io/en/latest/pages/install.html).

### Documentation
You can learn all about cogsworth from our collection of tutorials, examples and in-depth case studies on our online documentation [here](https://cogsworth.readthedocs.io/en/latest/index.html).
